@@ -2,7 +2,7 @@ import sys
 import unittest
 
 
-class CacheTestMixin(object):
+class CacheTestMixin:
 
     Cache = None
 
@@ -12,7 +12,7 @@ class CacheTestMixin(object):
         self.assertEqual(1, cache.maxsize)
         self.assertEqual(0, cache.currsize)
         self.assertEqual(1, cache.getsizeof(None))
-        self.assertEqual(1, cache.getsizeof(''))
+        self.assertEqual(1, cache.getsizeof(""))
         self.assertEqual(1, cache.getsizeof(0))
         self.assertTrue(repr(cache).startswith(cache.__class__.__name__))
 
@@ -47,10 +47,10 @@ class CacheTestMixin(object):
         self.assertEqual(1, cache[1])
         self.assertEqual(2, cache[2])
 
-        cache.update({1: 'a', 2: 'b'})
+        cache.update({1: "a", 2: "b"})
         self.assertEqual(2, len(cache))
-        self.assertEqual('a', cache[1])
-        self.assertEqual('b', cache[2])
+        self.assertEqual("a", cache[1])
+        self.assertEqual("b", cache[2])
 
     def test_delete(self):
         cache = self.Cache(maxsize=2)
@@ -108,7 +108,7 @@ class CacheTestMixin(object):
         with self.assertRaises(KeyError):
             cache.popitem()
 
-    @unittest.skipUnless(sys.version_info >= (3, 7), 'requires Python 3.7')
+    @unittest.skipUnless(sys.version_info >= (3, 7), "requires Python 3.7")
     def test_popitem_exception_context(self):
         # since Python 3.7, MutableMapping.popitem() suppresses
         # exception context as implementation detail
@@ -120,7 +120,14 @@ class CacheTestMixin(object):
         self.assertIsNone(exception.__cause__)
         self.assertTrue(exception.__suppress_context__)
 
-    def _test_missing(self, cache):
+    def test_missing(self):
+        class DefaultCache(self.Cache):
+            def __missing__(self, key):
+                self[key] = key
+                return key
+
+        cache = DefaultCache(maxsize=2)
+
         self.assertEqual(0, cache.currsize)
         self.assertEqual(2, cache.maxsize)
         self.assertEqual(0, len(cache))
@@ -172,30 +179,38 @@ class CacheTestMixin(object):
         self.assertTrue(1 in cache or 2 in cache)
         self.assertTrue(1 not in cache or 2 not in cache)
 
-    def _test_missing_getsizeof(self, cache):
-        self.assertEqual(0, cache.currsize)
-        self.assertEqual(2, cache.maxsize)
-        self.assertEqual(1, cache[1])
-        self.assertIn(1, cache)
-        self.assertEqual(2, cache[2])
-        self.assertNotIn(1, cache)
-        self.assertIn(2, cache)
-        self.assertEqual(3, cache[3])
-        self.assertNotIn(1, cache)
-        self.assertIn(2, cache)
-        self.assertNotIn(3, cache)
-
-    def test_missing_subclass(self):
-        class Cache(self.Cache):
+    def test_missing_getsizeof(self):
+        class DefaultCache(self.Cache):
             def __missing__(self, key):
                 try:
                     self[key] = key
                 except ValueError:
-                    pass
+                    pass  # not stored
                 return key
 
-        self._test_missing(Cache(maxsize=2))
-        self._test_missing_getsizeof(Cache(maxsize=2, getsizeof=lambda x: x))
+        cache = DefaultCache(maxsize=2, getsizeof=lambda x: x)
+
+        self.assertEqual(0, cache.currsize)
+        self.assertEqual(2, cache.maxsize)
+
+        self.assertEqual(1, cache[1])
+        self.assertEqual(1, len(cache))
+        self.assertEqual(1, cache.currsize)
+        self.assertIn(1, cache)
+
+        self.assertEqual(2, cache[2])
+        self.assertEqual(1, len(cache))
+        self.assertEqual(2, cache.currsize)
+        self.assertNotIn(1, cache)
+        self.assertIn(2, cache)
+
+        self.assertEqual(3, cache[3])  # not stored
+        self.assertEqual(1, len(cache))
+        self.assertEqual(2, cache.currsize)
+        self.assertEqual(1, cache[1])
+        self.assertEqual(1, len(cache))
+        self.assertEqual(1, cache.currsize)
+        self.assertEqual((1, 1), cache.popitem())
 
     def _test_getsizeof(self, cache):
         self.assertEqual(0, cache.currsize)
